import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, caleSqrt, scaleLinear, scaleTime, max, min, timeFormat, extent, pointRadial } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const margin = { top: 30, right: 30, bottom: 30, left: 30 };
const angleAxisOffset = 80;
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;
const fullCircle = 2 * Math.PI;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  console.log(data[0]);
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  const innerRadius = 180;
  const outerRadius = innerHeight / 2;
  

  const formatTime = timeFormat('%B');

  const xValue = d => d.DATE;
  const xAxisLabel = 'DATE';

  const yValue_dep = d => d.DEP_MEAN;
  const yValue_arr = d => d.ARR_MEAN;
  const yAxisLabel = 'Avg_Delay(mins)';

  const xAxisTickFormat = timeFormat('%b');

  const angleScale = scaleTime()
    .domain(d3.extent(data, xValue))
    .range([0, fullCircle]);

  console.log(angleScale.ticks());

  const radiusScale_dep = scaleLinear()
    .domain([0, max(data, yValue_dep)])
    .range([innerRadius, outerRadius])
    .nice();

  console.log(radiusScale_dep.ticks());

  const radiusScale_arr = scaleLinear()
    .domain([0, max(data, yValue_arr)])
    .range([innerRadius, outerRadius])
    .nice();

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${innerWidth/2 + margin.left}, ${innerHeight /2 + margin.top})`} >
        {angleScale.ticks().map(tickValue => ( 
          <g> 
            <line
              x1={pointRadial(angleScale(tickValue), innerRadius - angleAxisOffset)[0]}
              y1={pointRadial(angleScale(tickValue), innerRadius - angleAxisOffset)[1]}
              x2={pointRadial(angleScale(tickValue), outerRadius)[0]}
              y2={pointRadial(angleScale(tickValue), outerRadius)[1]}
              stroke="black"
            />
            
            <text x={pointRadial(angleScale(tickValue), outerRadius)[0]}
                  y={pointRadial(angleScale(tickValue), outerRadius)[1]}>
              {xAxisTickFormat(tickValue)}
            </text>

          </g>
        ))}

        <Marks
          data={data}
          angleScale={angleScale}
          radiusScale_dep={radiusScale_dep}
          radiusScale_arr={radiusScale_arr}
          xValue={xValue}
          yValue_dep={yValue_dep}
          yValue_arr={yValue_arr}
          tooltipFormat={xAxisTickFormat}
          circleRadius={1}
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
